# JSON file syntax

## Purpose and name

The `intros.json` file defines the tutorial (or 'intro') of each app. You can define an intro for any app you want, as well as the user/admin menu, and an app's aside.

The file has to be named `intros.json` and placed in a `data` folder at the root of the app.

## Syntax

**Overall syntax:**

```json
{
    "app1": {
        "name": "Canonical name",
        "steps": [...]
    },
    "app2": {
        "name": "Canonical name",
        "steps": [...]
    }
}
```

`app1` could be `files`, `calendar`... etc. It has to match the name of the app as displayed in the URL. The `name` field is the apps' name as it will be displayed in the settings menu. It can be anything you want. This field is required.

**Step syntax:**

```json
{
    "title": "A title",
    "paragraphs": ["Welcome!", "This <b>is</b> a paragraph"],
    "img": "img_url",
    "element": "query_to_element",
    "open": "query_to_element_to_open",
    "position": "left",
    "hover": true,
    "links": [...],
    "choices": [
        {
            "success": false,
            "label": "No"
        },
        {
            "success": true,
            "label": "Yay"
        }
    ]
}
```

- `title`: the title shown at the top of the tooltip. Optional.
- `paragraphs`: the text in the tooltip. Can be in HTML format. Optional, but you should put at least one paragraph
- `img`: the URL of an image. Will be shown before the text. Optional.
- `element`: the query of the element to focus. This field will be used by JS to find the element using `document.querySelector`. Optional: if not provided, or if the element couldn't be found, the tooltip will be shown in the middle of the viewport (default intro.js behaviour).
- `open`: the query of the element to click before focusing the `element`. This app can click on an element, e.g. to open a menu and focus on an element inside of it (that wouldn't be visible before clicking on it). Optional, has to be a clickable HTML element (e.g. a button).
- `position`: the position of the tooltip relative to the element it's focusing (see intro.js docs). Optional.
- `hover`: whether an element has to be hovered to be visible. Actually just sets the element's display style property to block while it is focused. Optional.
- `links`: a list of link to other apps to be displayed in the tooltip. The links lead to the related app and launches its intro. Optional.
- `choices`: providing a Yes/No choice to the user. The yes button will go to the next step, the no button will close the intro. Optional.

**Asides**

You can make a tour for the aside part of an app (the part that opens on the right, e.g. when opening the 'share' menu in *files*). You define it as a normal app, with a custom name. There are two possibilities:

- the section you want to focus on is the aside of an app : the name is `[app]-aside`
- the section you want to focus on is **a tab** in the aside of an app : the name is `[app]-aside-[tab_name]`. The tab name is taken from the element id in the HTML. For example, the section of the *sharing* tab in the *files* app has the `tab-sharing` id, so the tab name is `tab-sharing`.

Tours in asides will start automatically when the aside/tab is opened.

# Settings menu

This app features a menu in the personal user settings menu of Nextcloud. The user can enable or disable the tours from there. When a tour is enabled, it will play automativally when the user opens the related app.

![settings menu](./screenshots/settings.png "Settings menu")

The aside tours are linked to their upper app in this menu (enabling the intro for *files* will enable the one for the *sharing* tab of *files*), but not outside of it (marking the *files* tour as "not show again" at the end of it won't disable the *sharing* tour).

# Examples

![tooltip example](./screenshots/example.png "Tooltip example")

![choices example](./screenshots/choices.png "Choices example")

![links example](./screenshots/seeyou.png "Links example")

A "play again" button is displayed on the last tooltip of the tour. It is displayed automatically and keeps track of whether the user should see the tour for the associated app again or not.