<?php

namespace OCA\Intros\Controller;

use OCP\IConfig;
use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\DataResponse;
use OCP\IRequest;
use OCP\IL10N;

use OCA\Intros\AppInfo\Application;

class ConfigController extends Controller
{

    /**
     * @var IConfig
     */
    private $config;
    /**
     * @var string|null
     */
    private $userId;
    /** @var IL10N */
    private $l;

    public function __construct(
        string $appName,
        IRequest $request,
        IConfig $config,
        IL10N $l,
        ?string $userId
    ) {
        parent::__construct($appName, $request);
        $this->config = $config;
        $this->userId = $userId;
        $this->l = $l;
    }

    /**
     * @NoAdminRequired
     */
    public function saveConfig(string $key, string $value): DataResponse
    {
        $this->config->setUserValue($this->userId, Application::APP_ID, $key, $value);
        return new DataResponse([
            'message' => $this->l->t('Saved!'),
        ]);
    }
    
    /**
     * @NoAdminRequired
     */
    public function saveConfigs(array $appConfigs): DataResponse
    {
        foreach ($appConfigs as $key => $value) {
            $this->saveConfig($key, $value);
        }
        return new DataResponse([
            'message' => $this->l->t('Saved!')
        ]);
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     */
    public function getConfig(string $key): DataResponse
    {
        $configValue = $this->config->getUserValue($this->userId, Application::APP_ID, $key);

        return new DataResponse([
            'value' => $configValue,
            'userid' => $this->userId,
        ]);
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     */
    public function getConfigs(): DataResponse
    {
        $configValues = $this->config->getAllUserValues($this->userId);

        return new DataResponse([
            'values' => $configValues[Application::APP_ID],
            'userid' => $this->userId,
        ]);
    }
}
