<?php

namespace OCA\Intros\Settings;

use OCP\IURLGenerator;
use OCP\IL10N;
use OCP\Settings\IIconSection;

use OCA\Intros\AppInfo\Application;

class AdminSection implements IIconSection
{

	private IURLGenerator $urlGenerator;
	private IL10N $l;

	public function __construct(
		IURLGenerator $urlGenerator,
		IL10N         $l
	) {
		$this->urlGenerator = $urlGenerator;
		$this->l = $l;
	}

	/**
	 * returns the ID of the section. It is supposed to be a lower case string
	 *
	 * @returns string
	 */
	public function getID(): string
	{
		return Application::APP_ID; //or a generic id if feasible
	}

	/**
	 * returns the translated name as it should be displayed, e.g. 'LDAP / AD
	 * integration'. Use the L10N service to translate it.
	 *
	 * @return string
	 */
	public function getName(): string
	{
		return $this->l->t('Intros');
	}

	/**
	 * @return int whether the form should be rather on the top or bottom of
	 * the settings navigation. The sections are arranged in ascending order of
	 * the priority values. It is required to return a value between 0 and 99.
	 */
	public function getPriority(): int
	{
		return 80;
	}

	/**
	 * @return ?string The relative path to a an icon describing the section
	 */
	public function getIcon(): ?string
	{
		return $this->urlGenerator->imagePath(Application::APP_ID, 'app.svg');
	}
}
