/**
 * @copyright Copyright (c) 2022 John Molakvoæ <skjnldsv@protonmail.com>
 *
 * @author John Molakvoæ <skjnldsv@protonmail.com>
 *
 * @license AGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
import { Permission } from '../permissions';
import { NodeStatus } from './node';
export interface Attribute {
    [key: string]: any;
}
export interface NodeData {
    /** Unique ID */
    id?: number;
    /**
     * URL to the ressource.
     * e.g. https://cloud.domain.com/remote.php/dav/files/emma/Photos/picture.jpg
     * or https://domain.com/Photos/picture.jpg
     */
    source: string;
    /** Last modified time */
    mtime?: Date;
    /** Creation time */
    crtime?: Date;
    /** The mime type Optional for folders only */
    mime?: string;
    /** The node size type */
    size?: number;
    /** The node permissions */
    permissions?: Permission;
    /** The owner  UID of this node */
    owner: string | null;
    /** The node attributes */
    attributes?: Attribute;
    /**
     * The absolute root of the home relative to the service.
     * It is highly recommended to provide that information.
     * e.g. /files/emma
     */
    root?: string;
    /** The node status */
    status?: NodeStatus;
}
/**
 * Check if a node source is from a specific DAV service
 *
 * @param source The source to check
 * @param davService Pattern to check if source is DAV ressource
 */
export declare const isDavRessource: (source: string, davService: RegExp) => boolean;
/**
 * Validate Node construct data
 *
 * @param data The node data
 * @param davService Pattern to check if source is DAV ressource
 */
export declare const validateData: (data: NodeData, davService: RegExp) => void;
