/**
 * @copyright Copyright (c) 2021 Jonas Meurer <jonas@freesources.org>
 *
 * @author Jonas Meurer <jonas@freesources.org>
 *
 * @license AGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/**
 * Skin tones supported by Unicode Emojis (Fitzpatrick scale)
 * The numeric values align with `emoji-mart-vue`
 */
export declare enum EmojiSkinTone {
    Neutral = 1,
    Light = 2,
    MediumLight = 3,
    Medium = 4,
    MediumDark = 5,
    Dark = 6
}
/**
 * @param {string} query Emoji search string
 * @param {number} maxResults Maximum of returned emojis
 * @return {Array} list of found emojis
 */
export declare const emojiSearch: (query: string, maxResults?: number) => any;
export declare const emojiAddRecent: (id: any) => void;
/**
 * Get the current skin tone index used for emojis
 * @return {EmojiSkinTone} The skin tone
 */
export declare const getCurrentSkinTone: () => number;
/**
 * Set the current active skin tone for emojis
 * @param {EmojiSkinTone} skinTone Skin tone
 */
export declare const setCurrentSkinTone: (skinTone: EmojiSkinTone) => void;
